# MEMORY

### What should be saved here

Store all information that helps you work more efficiently. This is your persistent reference.

For example:

- Project information
- User settings and preferences related to skill execution
